#!/bin/bash

# auto_build.sh is a daily build script which can be configured to run daily using cron.

# WARNING: You will need to change some variables (below) to match your working environment.


# USAGE: ./auto_build.sh TARGET_DIRECTORY DATABASE_NAME DATABASE_HOST DATABASE_USER DATABASE_PASS
#				TARGET_DIRECTORY: The directory where the daily build should be stored.
#					(e.g. "./daily_build_folder/")
#               DATABASE_NAME: The desired database name. This database does not have to exist yet.
#                   (e.g. "cookingspecial_db")
#               DATABASE_HOST: The host name. Usually "localhost"
#               DATABASE_USER: A valid user in your database, which has root permissions.
#               DATABASE_PASS: The password for DATABASE_USER



# INFO: [Not required, but] ../BUILD.txt, ../INSTALL.txt, ../UNITTEST.txt for relevant information concerning daily builds and their content.

##################################################
# BEGIN CHANGE VARIABLES
##################################################
# The destination for the install. Assumed to preexist
TARGET_DIRECTORY=/homes/cubist/fluteman/www/test

# Your SVN checkout uri
SVN_CHECKOUT_URI=svn+ssh://attu.cs.washington.edu/projects/instr/09sp/cse403/cse403b/trunk/

# HTTP address (usually at localhost) at which to access the website once it has been sent to TARGET_DIRECTORY
DAILY_WWW_DIR=http://cubist.cs.washington.edu/~fluteman/test/src/website/www/

# You may also set default values for the arguments of auto_build.sh, and then call it with no arguments.
DATABASE_NAME=fluteman_test3
DATABASE_HOST=cubist.cs.washington.edu
DATABASE_USER=fluteman
DATABASE_PASS=hthjF78Z

# END CHANGE VARIABLES
##################################################

######################
# Usage
######################
if [ $# -gt 0 ]; then
	echo "Okay, doing variable assignments based on command line parameters"
	DATABASE_NAME=$1
	DATABASE_HOST=$2
	DATABASE_USER=$3
	DATABASE_PASS=$4
fi

######################
# Build script
######################

# print the current version.

# remove the old daily build
cd $TARGET_DIRECTORY 2> /dev/null
if [ "`pwd`" != "$TARGET_DIRECTORY" ]; then
    mkdir $TARGET_DIRECTORY
    cd $TARGET_DIRECTORY
fi
VERSION=`svn info | grep "Revision:" | awk '{print $2}'`
if [ "$VERSION" == "" ]; then
    VERSION=1
fi
echo "Removing old build ..." 
rm -rf * .* 2> /dev/null

# check out the latest copy into TARGET_DIRECTORY
echo ""
echo "Checking out latest copy ..."
svn checkout -q $SVN_CHECKOUT_URI .

# display all changes since the last daily build (from svn)
echo ""
echo "Log of changes since last daily build:"
svn log -r BASE:$VERSION
chmod -R a=rwx *

# install a fresh copy of the database using our install script
echo ""
echo "Installing database file ..."
links -dump -dump-width 150 $DAILY_WWW_DIR"install.php?submit=1&host="$DATABASE_HOST"&name="$DATABASE_NAME"&user="$DATABASE_USER"&password="$DATABASE_PASS"&exists=1&populate=1"

# run unit tests from target directory
echo ""
echo "Running Unit Tests ..."
bash $TARGET_DIRECTORY'/unittest.sh' $TARGET_DIRECTORY/src $DAILY_WWW_DIR
echo "All done!"
