<?php

/**
 * Handles requests for information about the user's favorite foods, saved specials, and saved recipes.
 * 
 * @package Controllers
 *
 */
class Favorite_Service_Controller extends AbstractController
{
	/**
	 * @ignore
	 */
	function __construct()
	{
		parent::__construct();
		$this->load->model('Favorites_Model', 'favorite');
		$this->load->model('User_Model', 'user');
	}

	/**
	 * Adds a special to the user's profile.
	 * @param int $specialId The special id to add.
	 */
	function addSpecial()
	{
		$error = false;
		if (!$this->user->isLoggedIn()) {
			$error = 'User not logged in.';
		}

		$specialId = Url::getInt('specialId');

		$this->favorite->addSpecial($this->user->id(), $specialId);

		$result = array(
			'success' => !$error,
			'error' => $error
		);

		echo json_encode($result);
	}

	/**
	 * Adds a recipe to the user's profile.
	 * 
	 * @param int $recipeId The recipe id to add.
	 */
	function addRecipe()
	{
		$error = false;
		if (!$this->user->isLoggedIn()) {
			$error = 'User not logged in.';
		}

		$recipeId = Url::getInt('recipeId');

		$this->favorite->addRecipe($this->user->id(), $recipeId);

		$result = array(
			'success' => !$error,
			'error' => $error
		);

		echo json_encode($result);

	}

	/**
	 * Removes a special from the user's profile.
	 * 
	 * @param int $specialId The special id to remove.
	 */
	function removeSpecial()
	{
		$error = false;
		$specialId = Url::getInt('specialId');
		if (!$this->user->isLoggedIn()) {
			$error = 'User not logged in.';
		}

		$this->favorite->removeSpecial($this->user->id(), $specialId);

		$result = array(
			'success' => !$error,
			'error' => $error
		);

		echo json_encode($result);
	}

	/**
	 * Removes a recipe from the user's profile.
	 * 
	 * @param int $recipeId The recipe id to remove.
	 */
	function removeRecipe()
	{
		$error = false;
		$recipeId = Url::getInt('recipeId');
		if (!$this->user->isLoggedIn()) {
			$error = 'User not logged in.';
		}

		$this->favorite->removeRecipe($this->user->id(), $recipeId);

		$result = array(
			'success' => !$error,
			'error' => $error
		);

		echo json_encode($result);
	}

	/**
	 * Adds a favorite food to the user's profile.
	 * 
	 * @param string $foodName The food item to add.
	 */
	function addFood()
	{
		$error = false;
		$foodName = Url::get('foodName');

		if (!$this->user->isLoggedIn()) {
			$error = 'User not logged in.';
		}

		$this->favorite->addFood($this->user->id(), $foodName);

		$result = array(
			'success' => !$error,
			'error' => $error,
		);

		echo json_encode($result);
	}

	/**
	 * Removes a favorite food from the user's profile.
	 * 
	 * @param string $foodName The food item to remove.
	 */
	function removeFood()
	{
		$error = false;
		$foodName = Url::get('foodName');

		if (!$this->user->isLoggedIn()) {
			$error = 'User not logged in.';
		}

		$this->favorite->removeFood($this->user->id(), $foodName);

		$result = array(
			'success' => !$error,
			'error' => $error,
		);

		echo json_encode($result);
	}
}

?>