<?php

/**
 * Handles login and logout requests, and user registration.
 *
 * @see login()
 * @see logout()
 * @see register()
 *
 * @package Controllers
 *
 */
class Login_Controller extends AbstractController
{
	/**
	 * The default action. Defaults to login()
	 * @see login()
	 */
	function index() { $this->login(); }

	/**
	 * Logs the user in.
	 * 
	 * @param string $username The username to log in with.
	 * @param string $password The password to log in with should match $username's password.
	 * @param string $redirect The page to redirect to when finished. If left blank, redirects to default controller.
	 * @param bool $json Specifies that we want JSON-style output. Used for AJAX calls. Defaults to false.
	 * 
	 */
	function login()
	{
		if (Url::getBool('register_submit')) {
			$this->register();
			return;
		}

		$this->load->model('User_Model', 'user');

		$username = Url::get('username');
		$password = md5(Url::get('password'));
		$redirect = Url::get('redirect');
		$json = Url::getBool('json');

		//
		// process login.
		// login user using information given
		$login_success = $this->user->login($username, $password);

		if ($json) {
			// return JSON object with relevant information
			$userinfo = $login_success ? $this->user->getArray() : null;
			$result = array(
				'login_success' => $login_success,
				'json' => $json,
				'form_username' => $username,
				'form_password' => $password,
				'userinfo' => $userinfo,
			);

			echo json_encode($result);
		} else if ($redirect) {
			// redirect to given url.
			Url::redirect($redirect);
		} else {
			// redirect to default controller if no redirect specified.
			include(TMVC_MYAPPDIR . 'configs' . DS . 'application.php');
			Url::redirect(Url::create($config['default_controller']));
		}
	}

	/**
	 * Logs the current user out.
	 * 
	 * @param string $redirect The page to redirect to when finished. If left blank, redirects to the default page.
	 * @param bool $json Specifies that we want JSON-style output. Used for AJAX calls. Defaults to false.
	 * 
	 */
	function logout()
	{
		$this->load->model('User_Model', 'user');

		$redirect = Url::get('redirect');

		// logout the user
		if ($this->user->isLoggedIn()) {
			$this->user->logout();
		}

		if ($redirect) {
			// redirect to given url.
			Url::redirect($redirect);
		} else {
			// redirect to default controller if no redirect specified.
			include(TMVC_MYAPPDIR . 'configs' . DS . 'application.php');
			Url::redirect(Url::create($config['default_controller']));
		}
	}

	/**
	 * Registers the user with the given information.
	 * 
	 * @param string $username The desired username.
	 * @param string $password The desired password.
	 * @param string $redirect Where to redirect after registration complete. If not specified, uses default controller.
	 */
	function register()
	{
		$this->load->model('User_Model', 'user');
		$redirect = Url::get('redirect');
		$username = Url::get('username');
		$password = Url::get('password');

		if ($this->user->isLoggedIn()) {
			Session_Handler::addError('Already logged in.', 'login');
			Url::redirect($redirect);
		}

		if ($this->user->register($username, $password)) {
			Session_Handler::addMessage('Registered successfully. You may now login with your new username and password.');
			$this->user->login($username, md5($password));
		}

		Url::redirect($redirect);
	}
}

?>