<?php

/**
 * Utility plugin which wraps several key pieces of URI-based functionality.
 * @package Plugins
 */
class Url
{
	/**
	 * Creates a uri string custom-tailored to CookingSpecial. This simplifies and abstracts the process of creating links.
	 */
	static function create($page = null, $action = null, $args = array(), $entity_decode = false)
	{
		$amp = ($entity_decode) ? '&' : '&amp;';
		if (!$page) {
			return 'index.php';
		}

		if (!$action) $action = 'index';

		$get_args = '';
		if (count($args) > 0) {
			$get_args = $amp . http_build_query($args);
		}

		return "index.php?page={$page}{$amp}action={$action}{$get_args}";
	}

	/**
	 * Retrieves a REQUEST argument (i.e. an argument from REQUEST.
	 * 
	 * @param string $argumentName The name of the argument to return.
	 * @see http://us3.php.net/manual/en/reserved.variables.request.php
	 * Returns the variable requested if $argumentName key is set, otherwise returns null.
	 */
	static function get($argumentName)
	{
		if (!empty($_REQUEST[$argumentName]))
			return $_REQUEST[$argumentName];
		else
			return null;
	}

	/**
	 * Retrieves an integer argument.
	 * @param string $argumentName The name of the argument to return.
	 */
	static function getInt($argumentName)
	{
		$result = Url::get($argumentName);
		return $result ? (int)$result : null;
	}

	/**
	 * Retrieves a boolean argument.
	 * @param string $argumentName The name of the argument to return.
	 */
	static function getBool($argumentName)
	{
		$result = Url::get($argumentName);
		return $result != null ? (bool)$result : false;
	}

	/**
	 * Redirects the user to the given url.
	 * 
	 * @param string $toUrl The url to redirect to.
	 * @param int $code [Optional] if headers already sent, the redirect code.
	 */
	static function redirect($toUrl, $code = 301)
	{
		$toUrl = html_entity_decode($toUrl);

		if (!headers_sent()) {
			header("Location: " . urldecode($toUrl));
			header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
			exit(0);
		}

		$location = null;
		$sn = $_SERVER['SCRIPT_NAME'];
		$cp = dirname($sn);
		if (substr($toUrl,0,4)=='http') $location = $toUrl; // Absolute URL
		else
		{
			$schema = $_SERVER['SERVER_PORT']=='443'?'https':'http';
			$host = strlen($_SERVER['HTTP_HOST'])?$_SERVER['HTTP_HOST']:$_SERVER['SERVER_NAME'];
			if (substr($toUrl,0,1)=='/') $location = "$schema://$host$toUrl";
			elseif (substr($toUrl,0,1)=='.') // Relative Path
			{
				$location = "$schema://$host/";
				$pu = parse_url($toUrl);
				$cd = dirname($_SERVER['SCRIPT_FILENAME']).'/';
				$np = realpath($cd.$pu['path']);
				$np = str_replace($_SERVER['DOCUMENT_ROOT'],'',$np);
				$location.= $np;
				if ((isset($pu['query'])) && (strlen($pu['query'])>0))
					$location.= '?'.$pu['query'];
			}
		}

		$hs = headers_sent();
		if ($hs==false)
		{
			if ($code==301) header("301 Moved Permanently HTTP/1.1"); // Convert to GET
			elseif ($code==302) header("302 Found HTTP/1.1"); // Conform re-POST
			elseif ($code==303) header("303 See Other HTTP/1.1"); // dont cache, always use GET
			elseif ($code==304) header("304 Not Modified HTTP/1.1"); // use cache
			elseif ($code==305) header("305 Use Proxy HTTP/1.1");
			elseif ($code==306) header("306 Not Used HTTP/1.1");
			elseif ($code==307) header("307 Temporary Redirect HTTP/1.1");
			else trigger_error("Unhandled redirect() HTTP Code: $code",E_USER_ERROR);
			header("Location: $location");
			header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
		}
		elseif (($hs==true) || ($code==302) || ($code==303))
		{
			// todo: change this to use smarty.
			echo "<p>Please See: <a href='$toUrl'>".htmlspecialchars($location)."</a></p>\n";
		}

		exit(0);
	}

}

?>